@@ -13,6 +13,7 @@
 #include <inttypes.h>
 #include <linux/limits.h>
 #include <getopt.h>
+#include <signal.h>
 #include "radix-tree.h"
 #include "endianness.h"
 
@@ -240,7 +241,7 @@ static void do_recursive_search(const char *path, struct workspace *ws, const de
             print_stats(ws);
         }
 
-        fd = open(path, O_RDONLY|O_NOFOLLOW|O_NOCTTY|O_NONBLOCK|__O_LARGEFILE);
+        fd = open(path, O_RDONLY|O_NOFOLLOW|O_NOCTTY|O_NONBLOCK);
         if (fd == -1)
         {
             if (errno == ELOOP    // symlink
